"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EndTaskCommand = void 0;
const core_1 = require("@loopback/core");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const keys_1 = require("../keys");
const types_1 = require("../types");
class EndTaskCommand {
    constructor(context) {
        this.context = context;
        this.topic = 'end-task';
        this.logger = context.getSync(core_2.LOGGER.LOGGER_INJECT);
    }
    async execute() {
        const job = this.parameters.taskService;
        const variables = this.parameters.task.variables.getAll();
        const taskId = variables.taskId;
        const tempContext = new core_1.Context(this.context);
        const systemUser = await tempContext.get(keys_1.TaskServiceBindings.SYSTEM_USER);
        tempContext.bind(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER).to(systemUser);
        try {
            const taskRepo = tempContext.getSync('repositories.TaskRepository');
            const outgoing = tempContext.getSync(keys_1.TaskServiceBindings.OUTGOING_CONNECTOR);
            await taskRepo.updateById(taskId, {
                status: types_1.TaskStatus.Completed,
            });
            await outgoing.publish({
                key: types_1.EventType.TaskCompleted,
                payload: {
                    taskId: taskId,
                },
                timestamp: Date.now(),
                source: types_1.Source.TaskService,
            });
            await job.complete(this.parameters.task);
        }
        catch (err) {
            await job.handleFailure(this.parameters.task, {
                errorMessage: err.message,
                errorDetails: err.stack,
            });
        }
        finally {
            tempContext.close();
        }
    }
}
exports.EndTaskCommand = EndTaskCommand;
//# sourceMappingURL=end-task.js.map