"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebhookSubscriptionController = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const models_1 = require("../../../models");
const services_1 = require("../services");
const baseUrl = '/webhooks';
let WebhookSubscriptionController = class WebhookSubscriptionController {
    constructor(apiKeyService, webhookService) {
        this.apiKeyService = apiKeyService;
        this.webhookService = webhookService;
    }
    async subscribeToWebhook(subscriber, request) {
        const apiKey = request.headers['x-api-key'];
        const apiSecret = request.headers['x-api-secret'];
        let isValidKeys = false;
        if (apiKey && apiSecret) {
            isValidKeys = await this.apiKeyService.verify(apiKey, apiSecret);
        }
        if (!isValidKeys) {
            throw new rest_1.HttpErrors.Unauthorized('Invalid API key or secret');
        }
        await this.webhookService.addToSubscription(subscriber.url, subscriber.key);
    }
};
exports.WebhookSubscriptionController = WebhookSubscriptionController;
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["16010" /* TaskPermssionKey.SubscribeToWebhook */] }),
    (0, rest_1.post)(`${baseUrl}/subscribe`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {},
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)()),
    tslib_1.__param(1, (0, core_1.inject)(rest_1.RestBindings.Http.REQUEST)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.SubscriberDTO, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], WebhookSubscriptionController.prototype, "subscribeToWebhook", null);
exports.WebhookSubscriptionController = WebhookSubscriptionController = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.service)(services_1.ApiKeyService)),
    tslib_1.__param(1, (0, core_1.service)(services_1.WebhookService)),
    tslib_1.__metadata("design:paramtypes", [services_1.ApiKeyService,
        services_1.WebhookService])
], WebhookSubscriptionController);
//# sourceMappingURL=webhook-subscription.controller.js.map