"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const baseUrl = 'tasks';
let TaskController = class TaskController {
    constructor(taskRepo, userTaskRepository, taskWorkflowMapping) {
        this.taskRepo = taskRepo;
        this.userTaskRepository = userTaskRepository;
        this.taskWorkflowMapping = taskWorkflowMapping;
    }
    async find(filter) {
        return this.taskRepo.find(filter);
    }
    async findById(id, filter) {
        return this.taskRepo.findById(id, filter);
    }
    async count(where) {
        return this.taskRepo.count(where);
    }
    async mapTaskToWorkflow(taskWorkflowMapping) {
        await this.taskWorkflowMapping.create(taskWorkflowMapping);
    }
    async deleteById(id, cascade = true) {
        if (cascade) {
            await this.userTaskRepository.deleteAllHard({
                taskId: id,
            });
        }
        await this.taskRepo.deleteByIdHard(id);
    }
    async delete(where, cascade = true) {
        if (cascade) {
            const tasks = await this.taskRepo.find({
                where,
                fields: ['id', 'deleted'],
            });
            if (tasks.length) {
                await this.userTaskRepository.deleteAllHard({
                    taskId: {
                        inq: tasks.map(task => task.id),
                    },
                });
            }
        }
        await this.taskRepo.deleteAllHard(where);
    }
};
exports.TaskController = TaskController;
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16003" /* TaskPermssionKey.ViewTask */],
    }),
    (0, rest_1.get)(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Array of Task model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.Task, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.filter(models_1.Task)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskController.prototype, "find", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16003" /* TaskPermssionKey.ViewTask */],
    }),
    (0, rest_1.get)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Task model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.Task, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.filter(models_1.Task, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskController.prototype, "findById", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16003" /* TaskPermssionKey.ViewTask */],
    }),
    (0, rest_1.get)(`${baseUrl}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Task model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.Task)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskController.prototype, "count", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["16006" /* TaskPermssionKey.MapTask */] }),
    (0, rest_1.post)(`${baseUrl}/mapping`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {},
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.TaskWorkflow, {
                    title: 'TaskWorkFlowMapping',
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskController.prototype, "mapTaskToWorkflow", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16008" /* TaskPermssionKey.DeleteTask */],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.del)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'Task DELETE by id success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.query.boolean('cascade')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskController.prototype, "deleteById", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16008" /* TaskPermssionKey.DeleteTask */],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.del)(`${baseUrl}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'Tasks DELETE success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.Task)),
    tslib_1.__param(1, rest_1.param.query.boolean('cascade')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskController.prototype, "delete", null);
exports.TaskController = TaskController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.TaskRepository)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.UserTaskRepository)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.TaskWorkFlowRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.TaskRepository,
        repositories_1.UserTaskRepository,
        repositories_1.TaskWorkFlowRepository])
], TaskController);
//# sourceMappingURL=task.controller.js.map