"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CamundaService = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const bpmn_service_1 = require("@sourceloop/bpmn-service");
// eslint-disable-next-line @typescript-eslint/naming-convention
const form_data_1 = tslib_1.__importDefault(require("form-data"));
const http_service_1 = require("./http.service");
let CamundaService = class CamundaService {
    constructor(http, config) {
        this.http = http;
        this.config = config;
        this.baseUrl = '';
        this.baseUrl = config === null || config === void 0 ? void 0 : config.workflowEngineBaseUrl;
    }
    async completeUserTask(id, variables) {
        return this.http.post(`${this.baseUrl}/task/${id}/complete`, {
            variables,
        });
    }
    async getPendingUserTasks(processDefinitionId) {
        return this.http.get(`${this.baseUrl}/task?processInstanceId=${processDefinitionId}`);
    }
    async create(name, file) {
        const form = new form_data_1.default();
        form.append(`${name}.bpmn`, file.toString('utf-8'), {
            filename: `${name}.bpmn`,
        });
        form.append('deployment-name', name);
        form.append('deploy-changed-only', String(true));
        return this.http.postFormData(`${this.baseUrl}/deployment/create`, form);
    }
    async delete(ids) {
        return Promise.all(ids.map(id => this.http.delete(`${this.baseUrl}/process-definition/${id}`, {
            query: {
                cascade: true,
            },
        })));
    }
    async deleteVersion(id) {
        return this.http.delete(`${this.baseUrl}/process-definition/${id}`);
    }
    async get(id) {
        return this.http.get(`${this.baseUrl}/process-definition/${id}`);
    }
    async execute(id, input) {
        return this.http.post(`${this.baseUrl}/process-definition/${id}/start`, {
            variables: this.formatInput(input),
        });
    }
    formatInput(input) {
        input.customHeaders = {
            url: process.env.LOGIN_URL,
            method: 'GET',
        };
        const inputObject = {};
        for (const key in input) {
            inputObject[key] = {
                value: typeof input[key] === 'object'
                    ? JSON.stringify(input[key])
                    : input[key],
            };
            if (typeof input[key] === 'object') {
                inputObject[key].type = 'object';
                inputObject[key].valueInfo = {
                    objectTypeName: 'java.util.LinkedHashMap',
                    serializationDataFormat: 'application/json',
                };
            }
        }
        return inputObject;
    }
};
exports.CamundaService = CamundaService;
exports.CamundaService = CamundaService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, core_1.service)(http_service_1.HttpClientService)),
    tslib_1.__param(1, (0, core_1.inject)(bpmn_service_1.WorkflowServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [http_service_1.HttpClientService, Object])
], CamundaService);
//# sourceMappingURL=camunda.service.js.map