"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventProcessorService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const bpmn_service_1 = require("@sourceloop/bpmn-service");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const keys_1 = require("../keys");
let EventProcessorService = class EventProcessorService {
    constructor(ctx, filter, logger) {
        this.ctx = ctx;
        this.filter = filter;
        this.logger = logger;
    }
    async handle(event) {
        var _a, _b;
        if (!this.filter(event)) {
            this.logger.debug(`Event ${event.key} filtered out`);
            return;
        }
        const tempContext = new core_1.Context(this.ctx, 'tempContext');
        const systemUser = await tempContext.get(keys_1.TaskServiceBindings.SYSTEM_USER);
        tempContext.bind(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER).to(systemUser);
        const repo = await tempContext.get(`repositories.EventRepository`);
        const eventWorkflowMappingRepo = await tempContext.get(`repositories.EventWorkflowRepository`);
        // need to add logic for event handling status
        await repo.create({
            key: event.key,
            payload: event.payload,
            source: (_a = event.payload.source) !== null && _a !== void 0 ? _a : event.source,
            description: (_b = event.payload.description) !== null && _b !== void 0 ? _b : `Task for ${event.key}`,
            timestamp: event.timestamp,
        });
        const mapping = await eventWorkflowMappingRepo.find({
            where: {
                eventKey: event.key,
            },
        });
        if (!mapping.length) {
            this.logger.debug(`No mapping found for event ${event.key}`);
            return;
        }
        const promises = mapping.map(async (map) => {
            await this._triggerWorkflow(map.workflowKey, event.payload, tempContext);
        });
        await Promise.all(promises);
        tempContext.close();
    }
    async _triggerWorkflow(workflowKey, payload, context) {
        const workflowCtrl = await context.get('controllers.WorkflowController');
        const workflowRepo = await context.get('repositories.WorkflowRepository');
        const workflow = await workflowRepo.findOne({
            where: {
                externalIdentifier: workflowKey,
            },
        });
        if (!workflow) {
            this.logger.debug(`No workflow found for key ${workflowKey}`);
        }
        else {
            await workflowCtrl.startWorkflow(workflow.id, new bpmn_service_1.ExecuteWorkflowDto({
                input: payload,
            }));
        }
    }
};
exports.EventProcessorService = EventProcessorService;
exports.EventProcessorService = EventProcessorService = tslib_1.__decorate([
    tslib_1.__param(0, core_1.inject.context()),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.TaskServiceBindings.EVENT_FILTER)),
    tslib_1.__param(2, (0, core_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [core_1.Context, Function, Object])
], EventProcessorService);
//# sourceMappingURL=event-processor.service.js.map